AppendStructRef

Trait AppendStructRef 

pub trait AppendStructRef {
    // Required method
    fn append_borrowed_into(&self, b: &mut StructBuilder);
}
Trait implemented by #[derive(Record)] structs to append their fields into a StructBuilder from a borrowed reference. This enables container builders (e.g., lists of structs) to append child values without taking ownership of the struct.

Required Methods

fn append_borrowed_into(&self, b: &mut StructBuilder)

Append this struct’s child values into the provided StructBuilder using borrows. Caller is responsible for setting the parent validity via append(true).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors